@@ -1,9 +1,10 @@
-import requests
+from time import sleep
+
+import dpp_common_utils.selenium
+from html_processing.parser import get_html_parser
 from lxml import etree
 from lxml.html import HtmlElement
 
-from html_processing.parser import get_html_parser
-
 
 def lxml_connect(url):
     """
@@ -13,10 +14,12 @@ def lxml_connect(url):
     :return: a Subclass of etree.ElementBase, dependent on what is specified in the parser
     :rtype: HtmlElement
     """
-    parser = get_html_parser()
-    user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:53.0) Gecko/20100101 Firefox/53.0'
-    headers = {'User-Agent': user_agent}
-    res = requests.get(url, headers=headers)
 
-    html_tree: HtmlElement = etree.fromstring(res.content, parser=parser)
+    parser = get_html_parser()
+    driver = dpp_common_utils.selenium.get_driver(True)
+    driver.get(url)
+    sleep(5)  # sleep - the script has to be loaded and this needs time
+    res = driver.page_source
+
+    html_tree: HtmlElement = etree.fromstring(res, parser=parser)
     return html_tree
